summaryrefslogtreecommitdiffstats
path: root/konq-plugins
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:52:34 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-04 03:25:49 +0200
commit19e67aed27e50319d00a06ae6287236db13f82f4 (patch)
tree6ab0b6ee6327f32fae59868408ef88e00d2cc2d9 /konq-plugins
parent0669339d48f65fc18388faefe54b239591d4705f (diff)
downloadtdeaddons-19e67aed27e50319d00a06ae6287236db13f82f4.tar.gz
tdeaddons-19e67aed27e50319d00a06ae6287236db13f82f4.zip
Remove additional unneeded tq method conversions
(cherry picked from commit 75112ed8e227f656f98523b7ffdad5422d9a6f11)
Diffstat (limited to 'konq-plugins')
-rw-r--r--konq-plugins/arkplugin/arkplugin.cpp8
-rw-r--r--konq-plugins/domtreeviewer/domlistviewitem.cpp4
-rw-r--r--konq-plugins/domtreeviewer/domlistviewitem.h2
-rw-r--r--konq-plugins/domtreeviewer/domtreecommands.cpp2
-rw-r--r--konq-plugins/domtreeviewer/domtreecommands.h4
-rw-r--r--konq-plugins/domtreeviewer/domtreeview.cpp12
-rw-r--r--konq-plugins/domtreeviewer/domtreeview.h2
-rw-r--r--konq-plugins/fsview/fsview.cpp20
-rw-r--r--konq-plugins/fsview/fsview_part.cpp2
-rw-r--r--konq-plugins/fsview/inode.cpp32
-rw-r--r--konq-plugins/fsview/inode.h2
-rw-r--r--konq-plugins/fsview/treemap.cpp140
-rw-r--r--konq-plugins/fsview/treemap.h24
-rw-r--r--konq-plugins/kimgalleryplugin/imgallerydialog.cpp4
-rw-r--r--konq-plugins/kimgalleryplugin/imgalleryplugin.cpp16
-rw-r--r--konq-plugins/kuick/kdirmenu.cpp8
-rw-r--r--konq-plugins/kuick/kdirmenu.h2
-rw-r--r--konq-plugins/rellinks/plugin_rellinks.cpp4
-rw-r--r--konq-plugins/searchbar/searchbar.cpp8
-rw-r--r--konq-plugins/sidebar/delicious/mainWidget.cpp4
-rw-r--r--konq-plugins/sidebar/metabar/src/defaultplugin.cpp6
-rw-r--r--konq-plugins/sidebar/metabar/src/metabarfunctions.cpp16
-rw-r--r--konq-plugins/sidebar/metabar/src/metabarwidget.cpp14
-rw-r--r--konq-plugins/sidebar/metabar/src/protocolplugin.cpp6
-rw-r--r--konq-plugins/uachanger/uachangerplugin.cpp10
-rw-r--r--konq-plugins/validators/plugin_validators.cpp2
-rw-r--r--konq-plugins/webarchiver/archivedialog.cpp6
-rw-r--r--konq-plugins/webarchiver/plugin_webarchiver.cpp4
28 files changed, 182 insertions, 182 deletions
diff --git a/konq-plugins/arkplugin/arkplugin.cpp b/konq-plugins/arkplugin/arkplugin.cpp
index 6c49555..f2bfa7e 100644
--- a/konq-plugins/arkplugin/arkplugin.cpp
+++ b/konq-plugins/arkplugin/arkplugin.cpp
@@ -98,7 +98,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
{
item = itemList.first();
m_name = itemList.first()->name();
- action = new KAction( i18n( "Compress as %1" ).tqarg( m_name + m_ext ), 0, this,
+ action = new KAction( i18n( "Compress as %1" ).arg( m_name + m_ext ), 0, this,
TQT_SLOT( slotCompressAsDefault() ), actionCollection() );
}
else
@@ -143,7 +143,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
{
TQString targetName = itemList.first()->name();
stripExtension( targetName );
- action = new KAction( i18n( "Extract to %1" ).tqarg( targetName ), 0, this,
+ action = new KAction( i18n( "Extract to %1" ).arg( targetName ), 0, this,
TQT_SLOT( slotExtractToSubfolders() ), actionCollection() );
}
else
@@ -473,7 +473,7 @@ void ArkMenu::slotCompressAs( int pos )
int i=1;
while ( KIO::NetAccess::exists(target, true, 0 ) )
{
- target = m_dir + i18n("Archive %1").tqarg(i) + m_extensionList[ pos ];
+ target = m_dir + i18n("Archive %1").arg(i) + m_extensionList[ pos ];
i++;
}
}
@@ -517,7 +517,7 @@ void ArkMenu::slotCompressAsDefault()
int i=1;
while ( KIO::NetAccess::exists(name, true, 0 ) )
{
- name = m_dir + i18n("Archive %1").tqarg(i) + m_ext;
+ name = m_dir + i18n("Archive %1").arg(i) + m_ext;
i++;
}
}
diff --git a/konq-plugins/domtreeviewer/domlistviewitem.cpp b/konq-plugins/domtreeviewer/domlistviewitem.cpp
index 8951451..7ab20b4 100644
--- a/konq-plugins/domtreeviewer/domlistviewitem.cpp
+++ b/konq-plugins/domtreeviewer/domlistviewitem.cpp
@@ -59,14 +59,14 @@ void DOMListViewItem::init()
clos = false;
}
-void DOMListViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
+void DOMListViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
{
TQColorGroup _cg( cg );
TQColor c = _cg.text();
p->setFont(m_font);
_cg.setColor( TQColorGroup::Text, m_color );
- TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
+ TQListViewItem::paintCell( p, _cg, column, width, alignment );
_cg.setColor( TQColorGroup::Text, c );
}
diff --git a/konq-plugins/domtreeviewer/domlistviewitem.h b/konq-plugins/domtreeviewer/domlistviewitem.h
index 3ba7378..f6f74f6 100644
--- a/konq-plugins/domtreeviewer/domlistviewitem.h
+++ b/konq-plugins/domtreeviewer/domlistviewitem.h
@@ -33,7 +33,7 @@ class DOMListViewItem : public TQListViewItem
virtual ~DOMListViewItem();
virtual void paintCell( TQPainter *p, const TQColorGroup &cg,
- int column, int width, int tqalignment );
+ int column, int width, int alignment );
void setColor( const TQColor &color) { m_color = color; }
diff --git a/konq-plugins/domtreeviewer/domtreecommands.cpp b/konq-plugins/domtreeviewer/domtreecommands.cpp
index a072409..5837239 100644
--- a/konq-plugins/domtreeviewer/domtreecommands.cpp
+++ b/konq-plugins/domtreeviewer/domtreecommands.cpp
@@ -53,7 +53,7 @@ static const char * const dom_error_msgs[] = {
TQString domtreeviewer::domErrorMessage(int dom_err)
{
if ((unsigned)dom_err > sizeof dom_error_msgs/sizeof dom_error_msgs[0])
- return i18n("Unknown Exception %1").tqarg(dom_err);
+ return i18n("Unknown Exception %1").arg(dom_err);
else
return i18n(dom_error_msgs[dom_err]);
}
diff --git a/konq-plugins/domtreeviewer/domtreecommands.h b/konq-plugins/domtreeviewer/domtreecommands.h
index 6361fd7..eed0822 100644
--- a/konq-plugins/domtreeviewer/domtreecommands.h
+++ b/konq-plugins/domtreeviewer/domtreecommands.h
@@ -305,7 +305,7 @@ class InsertNodeCommand : public ManipulateNodeCommand
public:
/**
* Prepare insertion command, inserting \c node into \c parent, just
- * before \c after. If \c after is 0, append it to the list of tqchildren.
+ * before \c after. If \c after is 0, append it to the list of children.
*/
InsertNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~InsertNodeCommand();
@@ -331,7 +331,7 @@ class RemoveNodeCommand : public ManipulateNodeCommand
public:
/**
* Prepare insertion command, inserting \c node into \c parent, just
- * before \c after. If \c after is 0, append it to the list of tqchildren.
+ * before \c after. If \c after is 0, append it to the list of children.
*/
RemoveNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
virtual ~RemoveNodeCommand();
diff --git a/konq-plugins/domtreeviewer/domtreeview.cpp b/konq-plugins/domtreeviewer/domtreeview.cpp
index 615f056..4a15a2b 100644
--- a/konq-plugins/domtreeviewer/domtreeview.cpp
+++ b/konq-plugins/domtreeviewer/domtreeview.cpp
@@ -124,7 +124,7 @@ void DOMTreeView::setHtmlPart(KHTMLPart *_part)
// nothing here yet
}
- parentWidget()->setCaption( part ? i18n( "DOM Tree for %1" ).tqarg(part->url().prettyURL()) : i18n("DOM Tree") );
+ parentWidget()->setCaption( part ? i18n( "DOM Tree for %1" ).arg(part->url().prettyURL()) : i18n("DOM Tree") );
TQTimer::singleShot(0, this, TQT_SLOT(slotSetHtmlPartDelayed()));
}
@@ -530,7 +530,7 @@ void DOMTreeView::slotSaveClicked()
if (file.exists()) {
const TQString title = i18n( "File Exists" );
- const TQString text = i18n( "Do you really want to overwrite: \n%1?" ).tqarg(url.url());
+ const TQString text = i18n( "Do you really want to overwrite: \n%1?" ).arg(url.url());
if (KMessageBox::Continue != KMessageBox::warningContinueCancel(this, text, title, i18n("Overwrite") ) ) {
return;
}
@@ -545,12 +545,12 @@ void DOMTreeView::slotSaveClicked()
delete m_textStream;
} else {
const TQString title = i18n( "Unable to Open File" );
- const TQString text = i18n( "Unable to open \n %1 \n for writing" ).tqarg(url.path());
+ const TQString text = i18n( "Unable to open \n %1 \n for writing" ).arg(url.path());
KMessageBox::sorry( this, text, title );
}
} else {
const TQString title = i18n( "Invalid URL" );
- const TQString text = i18n( "This URL \n %1 \n is not valid." ).tqarg(url.url());
+ const TQString text = i18n( "This URL \n %1 \n is not valid." ).arg(url.url());
KMessageBox::sorry( this, text, title );
}
}
@@ -973,7 +973,7 @@ public:
protected:
virtual void paintCell( TQPainter *p, const TQColorGroup &cg,
- int column, int width, int tqalignment )
+ int column, int width, int alignment )
{
bool updates_enabled = listView()->isUpdatesEnabled();
listView()->setUpdatesEnabled(false);
@@ -993,7 +993,7 @@ protected:
TQColorGroup _cg( cg );
_cg.setColor( TQColorGroup::Text, c );
- super::paintCell( p, _cg, column, width, tqalignment );
+ super::paintCell( p, _cg, column, width, alignment );
if (text_changed) setText(column, oldText);
listView()->setUpdatesEnabled(updates_enabled);
diff --git a/konq-plugins/domtreeviewer/domtreeview.h b/konq-plugins/domtreeviewer/domtreeview.h
index 6ff1634..43c389c 100644
--- a/konq-plugins/domtreeviewer/domtreeview.h
+++ b/konq-plugins/domtreeviewer/domtreeview.h
@@ -169,7 +169,7 @@ class DOMTreeView : public DOMTreeViewBase
// == DOM Node Info panel ======================================
public:
- // Keep in sync with the widget stack tqchildren
+ // Keep in sync with the widget stack children
enum InfoPanel { ElementPanel, CDataPanel, EmptyPanel };
public slots:
diff --git a/konq-plugins/fsview/fsview.cpp b/konq-plugins/fsview/fsview.cpp
index 830bb3d..931c43f 100644
--- a/konq-plugins/fsview/fsview.cpp
+++ b/konq-plugins/fsview/fsview.cpp
@@ -94,12 +94,12 @@ FSView::FSView(Inode* base, TQWidget* parent, const char* name)
double s;
TQString str;
for (i=1;i<=ccount;i++) {
- str = TQString("Dir%1").tqarg(i);
+ str = TQString("Dir%1").arg(i);
if (!cconfig.hasKey(str)) continue;
str = cconfig.readPathEntry(str);
- s = cconfig.readDoubleNumEntry(TQString("Size%1").tqarg(i), 0.0);
- f = cconfig.readNumEntry(TQString("Files%1").tqarg(i), 0);
- d = cconfig.readNumEntry(TQString("Dirs%1").tqarg(i), 0);
+ s = cconfig.readDoubleNumEntry(TQString("Size%1").arg(i), 0.0);
+ f = cconfig.readNumEntry(TQString("Files%1").arg(i), 0);
+ d = cconfig.readNumEntry(TQString("Dirs%1").arg(i), 0);
if (s==0.0 || f==0 || d==0) continue;
setDirMetric(str, s, f, d);
}
@@ -147,7 +147,7 @@ void FSView::setPath(TQString p)
b->setPeer(d);
- setCaption(TQString("%1 - FSView").tqarg(_path));
+ setCaption(TQString("%1 - FSView").arg(_path));
requestUpdate(b);
}
@@ -286,7 +286,7 @@ void FSView::contextMenu(TreeMapItem* i, const TQPoint& p)
popup.insertItem(i18n("Refresh"), 5);
popup.setItemEnabled(5, !_sm.scanRunning());
- if (i) popup.insertItem(i18n("Refresh '%1'").tqarg(i->text(0)), 4);
+ if (i) popup.insertItem(i18n("Refresh '%1'").arg(i->text(0)), 4);
popup.insertSeparator();
addDepthStopItems(dpopup, 1001, i);
popup.insertItem(i18n("Stop at Depth"), dpopup, 1000);
@@ -331,10 +331,10 @@ void FSView::saveMetric(KConfigGroup* g)
TQMap<TQString, MetricEntry>::iterator it;
int c = 1;
for (it=_dirMetric.begin();it!=_dirMetric.end();++it) {
- g->writePathEntry(TQString("Dir%1").tqarg(c), it.key());
- g->writeEntry(TQString("Size%1").tqarg(c), (*it).size);
- g->writeEntry(TQString("Files%1").tqarg(c), (*it).fileCount);
- g->writeEntry(TQString("Dirs%1").tqarg(c), (*it).dirCount);
+ g->writePathEntry(TQString("Dir%1").arg(c), it.key());
+ g->writeEntry(TQString("Size%1").arg(c), (*it).size);
+ g->writeEntry(TQString("Files%1").arg(c), (*it).fileCount);
+ g->writeEntry(TQString("Dirs%1").arg(c), (*it).dirCount);
c++;
}
g->writeEntry("Count", c-1);
diff --git a/konq-plugins/fsview/fsview_part.cpp b/konq-plugins/fsview/fsview_part.cpp
index 0d5eda7..5182dbe 100644
--- a/konq-plugins/fsview/fsview_part.cpp
+++ b/konq-plugins/fsview/fsview_part.cpp
@@ -74,7 +74,7 @@ void FSJob::progressSlot(int percent, int dirs, const TQString& cDir)
emitPercent(percent, 100);
slotInfoMessage(this, i18n("Read 1 folder, in %1",
"Read %n folders, in %1",
- dirs ).tqarg(cDir));
+ dirs ).arg(cDir));
}
else
slotInfoMessage(this, i18n("1 folder", "%n folders", dirs));
diff --git a/konq-plugins/fsview/inode.cpp b/konq-plugins/fsview/inode.cpp
index c84f5d5..6f5073c 100644
--- a/konq-plugins/fsview/inode.cpp
+++ b/konq-plugins/fsview/inode.cpp
@@ -168,7 +168,7 @@ void Inode::destroyed(ScanDir* d)
{
if (_dirPeer == d) _dirPeer = 0;
- // remove tqchildren
+ // remove children
clear();
}
@@ -179,15 +179,15 @@ void Inode::destroyed(ScanFile* f)
-TreeMapItemList* Inode::tqchildren()
+TreeMapItemList* Inode::children()
{
if (!_dirPeer) return 0;
- if (!_tqchildren) {
+ if (!_children) {
if (!_dirPeer->scanStarted()) return 0;
- _tqchildren = new TreeMapItemList;
- _tqchildren->setAutoDelete(true);
+ _children = new TreeMapItemList;
+ _children->setAutoDelete(true);
setSorting(-1);
@@ -215,7 +215,7 @@ TreeMapItemList* Inode::tqchildren()
_resortNeeded = false;
}
- return _tqchildren;
+ return _children;
}
@@ -325,21 +325,21 @@ TQString Inode::text(int i) const
double s = size();
if (s < 1000)
- text = TQString("%1 B").tqarg((int)(s+.5));
+ text = TQString("%1 B").arg((int)(s+.5));
else if (s < 10 * 1024)
- text = TQString("%1 kB").tqarg(KGlobal::locale()->formatNumber(s/1024+.005,2));
+ text = TQString("%1 kB").arg(KGlobal::locale()->formatNumber(s/1024+.005,2));
else if (s < 100 * 1024)
- text = TQString("%1 kB").tqarg(KGlobal::locale()->formatNumber(s/1024+.05,1));
+ text = TQString("%1 kB").arg(KGlobal::locale()->formatNumber(s/1024+.05,1));
else if (s < 1000 * 1024)
- text = TQString("%1 kB").tqarg((int)(s/1024+.5));
+ text = TQString("%1 kB").arg((int)(s/1024+.5));
else if (s < 10 * 1024 * 1024)
- text = TQString("%1 MB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024+.005,2));
+ text = TQString("%1 MB").arg(KGlobal::locale()->formatNumber(s/1024/1024+.005,2));
else if (s < 100 * 1024 * 1024)
- text = TQString("%1 MB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024+.05,1));
+ text = TQString("%1 MB").arg(KGlobal::locale()->formatNumber(s/1024/1024+.05,1));
else if (s < 1000 * 1024 * 1024)
- text = TQString("%1 MB").tqarg((int)(s/1024/1024+.5));
+ text = TQString("%1 MB").arg((int)(s/1024/1024+.5));
else
- text = TQString("%1 GB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024/1024+.005,2));
+ text = TQString("%1 GB").arg(KGlobal::locale()->formatNumber(s/1024/1024/1024+.005,2));
if (_sizeEstimation>0) text += "+";
return text;
@@ -354,10 +354,10 @@ TQString Inode::text(int i) const
if (f>0) {
while (f>1000) {
- text = TQString("%1 %2").tqarg(TQString::number(f).right(3)).tqarg(text);
+ text = TQString("%1 %2").arg(TQString::number(f).right(3)).arg(text);
f /= 1000;
}
- text = TQString("%1 %2").tqarg(TQString::number(f)).tqarg(text);
+ text = TQString("%1 %2").arg(TQString::number(f)).arg(text);
if (_fileCountEstimation>0) text += "+";
}
return text;
diff --git a/konq-plugins/fsview/inode.h b/konq-plugins/fsview/inode.h
index d21a689..eb1e3dd 100644
--- a/konq-plugins/fsview/inode.h
+++ b/konq-plugins/fsview/inode.h
@@ -53,7 +53,7 @@ public:
void setPeer(ScanDir*);
- TreeMapItemList* tqchildren();
+ TreeMapItemList* children();
double value() const;
double size() const;
diff --git a/konq-plugins/kimgalleryplugin/imgallerydialog.cpp b/konq-plugins/kimgalleryplugin/imgallerydialog.cpp
index 671b90e..d5fe29a 100644
--- a/konq-plugins/kimgalleryplugin/imgallerydialog.cpp
+++ b/konq-plugins/kimgalleryplugin/imgallerydialog.cpp
@@ -60,7 +60,7 @@ KIGPDialog::KIGPDialog(TQWidget *parent, const TQString& path, const char *name
void KIGPDialog::slotDefault()
{
- m_title->setText(i18n("Image Gallery for %1").tqarg(m_path));
+ m_title->setText(i18n("Image Gallery for %1").arg(m_path));
m_imagesPerRow->setValue(4);
m_imageName->setChecked(true);
m_imageSize->setChecked(false);
@@ -96,7 +96,7 @@ void KIGPDialog::setupLookPage(const TQString& path) {
label = new TQLabel( i18n("&Page title:"), page);
vlay->addWidget(label);
- m_title = new TQLineEdit(i18n("Image Gallery for %1").tqarg(path), page);
+ m_title = new TQLineEdit(i18n("Image Gallery for %1").arg(path), page);
vlay->addWidget( m_title );
label->setBuddy(m_title);
diff --git a/konq-plugins/kimgalleryplugin/imgalleryplugin.cpp b/konq-plugins/kimgalleryplugin/imgalleryplugin.cpp
index bae46bf..47dbff1 100644
--- a/konq-plugins/kimgalleryplugin/imgalleryplugin.cpp
+++ b/konq-plugins/kimgalleryplugin/imgalleryplugin.cpp
@@ -105,7 +105,7 @@ bool KImGalleryPlugin::createDirectory(TQDir thumb_dir, TQString imgGalleryDir,
if (!thumb_dir.exists()) {
thumb_dir.setPath( imgGalleryDir);
if (!(thumb_dir.mkdir(dirName, false))) {
- KMessageBox::sorry(m_part->widget(), i18n("Couldn't create folder: %1").tqarg(thumb_dir.path()));
+ KMessageBox::sorry(m_part->widget(), i18n("Couldn't create folder: %1").arg(thumb_dir.path()));
return false;
} else {
thumb_dir.setPath( imgGalleryDir + "/" + dirName + "/" );
@@ -166,8 +166,8 @@ void KImGalleryPlugin::createBody(TQTextStream& stream, const TQString& sourceDi
const TQString today(KGlobal::locale()->formatDate(TQDate::currentDate()));
stream << "<body>\n<h1>" << TQStyleSheet::escape(m_configDlg->getTitle()) << "</h1><p>" << endl;
- stream << i18n("<i>Number of images</i>: %1").tqarg(numOfImages) << "<br/>" << endl;
- stream << i18n("<i>Created on</i>: %1").tqarg(today) << "</p>" << endl;
+ stream << i18n("<i>Number of images</i>: %1").arg(numOfImages) << "<br/>" << endl;
+ stream << i18n("<i>Created on</i>: %1").arg(today) << "</p>" << endl;
stream << "<hr/>" << endl;
@@ -205,10 +205,10 @@ void KImGalleryPlugin::createBody(TQTextStream& stream, const TQString& sourceDi
const TQString imgPath("thumbs/" + imgName + extension(imageFormat));
stream << "<img src=\"" << imgPath << "\" width=\"" << m_imgWidth << "\" ";
stream << "height=\"" << m_imgHeight << "\" alt=\"" << imgPath << "\"/>";
- m_progressDlg->setLabelText( i18n("Created thumbnail for: \n%1").tqarg(imgName) );
+ m_progressDlg->setLabelText( i18n("Created thumbnail for: \n%1").arg(imgName) );
} else {
kdDebug(90170) << "Creating thumbnail for " << imgName << " failed" << endl;
- m_progressDlg->setLabelText( i18n("Creating thumbnail for: \n%1\n failed").tqarg(imgName) );
+ m_progressDlg->setLabelText( i18n("Creating thumbnail for: \n%1\n failed").arg(imgName) );
}
stream << "</a>" << endl;
@@ -266,7 +266,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const TQString& sourceDirName
if (!subDir.exists()) {
subDir.setPath( url.directory() );
if (!(subDir.mkdir(currentDir, false))) {
- KMessageBox::sorry(part->widget(), i18n("Couldn't create folder: %1").tqarg(subDir.path()));
+ KMessageBox::sorry(part->widget(), i18n("Couldn't create folder: %1").arg(subDir.path()));
continue;
} else {
subDir.setPath( url.directory() + "/" + currentDir );
@@ -320,7 +320,7 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const TQString& sourceDirName
return !m_cancelled;
} else {
- KMessageBox::sorry(m_part->widget(),i18n("Couldn't open file: %1").tqarg(url.path(+1)));
+ KMessageBox::sorry(m_part->widget(),i18n("Couldn't open file: %1").arg(url.path(+1)));
return false;
}
}
@@ -415,7 +415,7 @@ void KImGalleryPlugin::loadCommentFile()
kdDebug(90170) << "File closed." << endl;
delete m_textStream;
} else {
- KMessageBox::sorry(m_part->widget(), i18n("Couldn't open file: %1").tqarg(m_configDlg->getCommentFile()));
+ KMessageBox::sorry(m_part->widget(), i18n("Couldn't open file: %1").arg(m_configDlg->getCommentFile()));
m_useCommentFile = false;
}
}
diff --git a/konq-plugins/kuick/kdirmenu.cpp b/konq-plugins/kuick/kdirmenu.cpp
index b9fa89d..030ac98 100644
--- a/konq-plugins/kuick/kdirmenu.cpp
+++ b/konq-plugins/kuick/kdirmenu.cpp
@@ -42,11 +42,11 @@ KDirMenu::KDirMenu ( TQWidget *parent, const KURL &_src,
src( _src ),
action( 0 )
{
- tqchildren.setAutoDelete( true );
+ children.setAutoDelete( true );
initIconMap( );
connect( this, TQT_SIGNAL( aboutToShow( ) ), this, TQT_SLOT( slotAboutToShow( ) ) );
connect( this, TQT_SIGNAL( aboutToHide( ) ), this, TQT_SLOT( slotAboutToHide( ) ) );
- tqchildren.clear(); // just in case
+ children.clear(); // just in case
TQFileInfo fileInfo(path);
if (( src.path() != path || !src.isLocalFile()) && fileInfo.isWritable())
@@ -55,7 +55,7 @@ KDirMenu::KDirMenu ( TQWidget *parent, const KURL &_src,
KDirMenu::~KDirMenu( ) {
delete action;
clear( );
- tqchildren.clear( );
+ children.clear( );
}
void KDirMenu::insert( KDirMenu *submenu, const TQString &_path ) {
static const TQIconSet folder = SmallIconSet("folder");
@@ -80,7 +80,7 @@ void KDirMenu::insert( KDirMenu *submenu, const TQString &_path ) {
}
else
insertItem( folder, escapedPath.replace( "&", "&&" ), submenu );
- tqchildren.append( submenu );
+ children.append( submenu );
connect(submenu, TQT_SIGNAL(fileChosen(const TQString &)),
this, TQT_SLOT(slotFileSelected(const TQString &)));
}
diff --git a/konq-plugins/kuick/kdirmenu.h b/konq-plugins/kuick/kdirmenu.h
index 979fdf6..f4bd6bf 100644
--- a/konq-plugins/kuick/kdirmenu.h
+++ b/konq-plugins/kuick/kdirmenu.h
@@ -48,7 +48,7 @@ private:
TQString name;
KURL src;
KAction *action;
- TQPtrList<KDirMenu> tqchildren;
+ TQPtrList<KDirMenu> children;
void initIconMap( );
public slots:
void slotAboutToShow( );
diff --git a/konq-plugins/rellinks/plugin_rellinks.cpp b/konq-plugins/rellinks/plugin_rellinks.cpp
index 7b2d61b..53c1e37 100644
--- a/konq-plugins/rellinks/plugin_rellinks.cpp
+++ b/konq-plugins/rellinks/plugin_rellinks.cpp
@@ -394,7 +394,7 @@ void RelLinksPlugin::guessRelations()
TQString href=rx.cap(1)+ nval_str + rx.cap(3);
KURL ref( m_part->url(), href );
- TQString title = i18n("[Autodetected] %1").tqarg(ref.prettyURL());
+ TQString title = i18n("[Autodetected] %1").arg(ref.prettyURL());
DOM::Element e= m_part->document().createElement("link");
e.setAttribute("href",href);
element_map["next"][0] = e;
@@ -408,7 +408,7 @@ void RelLinksPlugin::guessRelations()
nval_str.prepend(zeros.left(lenval-nval_str.length()));
TQString href=rx.cap(1)+ nval_str + rx.cap(3);
KURL ref( m_part->url(), href );
- TQString title = i18n("[Autodetected] %1").tqarg(ref.prettyURL());
+ TQString title = i18n("[Autodetected] %1").arg(ref.prettyURL());
e= m_part->document().createElement("link");
e.setAttribute("href",href);
element_map["prev"][0] = e;
diff --git a/konq-plugins/searchbar/searchbar.cpp b/konq-plugins/searchbar/searchbar.cpp
index d099e7e..4da4d30 100644
--- a/konq-plugins/searchbar/searchbar.cpp
+++ b/konq-plugins/searchbar/searchbar.cpp
@@ -273,7 +273,7 @@ void SearchBarPlugin::startSearch(const TQString &_search)
TQStringList list;
list << "kurisearchfilter" << "kuriikwsfilter";
- service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(m_currentEngine));
+ service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(m_currentEngine));
if (service) {
const TQString searchProviderPrefix = *(service->property("Keys").toStringList().begin()) + delimiter();
data.setData( searchProviderPrefix + search );
@@ -329,7 +329,7 @@ void SearchBarPlugin::setIcon()
TQStringList list;
list << "kurisearchfilter" << "kuriikwsfilter";
- service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(m_currentEngine));
+ service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(m_currentEngine));
if (service) {
const TQString searchProviderPrefix = *(service->property("Keys").toStringList().begin()) + delimiter();
data.setData( searchProviderPrefix + "some keyword" );
@@ -353,7 +353,7 @@ void SearchBarPlugin::setIcon()
m_searchIcon = SmallIcon("google");
providername = "Google";
}
- hinttext = i18n("%1 Search").tqarg(providername);;
+ hinttext = i18n("%1 Search").arg(providername);;
}
static_cast<KLineEdit*>(m_searchCombo->lineEdit())->setClickMessage(hinttext);
@@ -389,7 +389,7 @@ void SearchBarPlugin::showSelectionMenu()
for (TQStringList::ConstIterator it = m_searchEngines.begin(); it != m_searchEngines.end(); ++it )
{
i++;
- service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(*it));
+ service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(*it));
if(!service)
{
continue;
diff --git a/konq-plugins/sidebar/delicious/mainWidget.cpp b/konq-plugins/sidebar/delicious/mainWidget.cpp
index 3f3b03a..612be03 100644
--- a/konq-plugins/sidebar/delicious/mainWidget.cpp
+++ b/konq-plugins/sidebar/delicious/mainWidget.cpp
@@ -302,7 +302,7 @@ void MainWidget::slotRenameTag()
if ( tag )
{
TQString oldName = tag->name();
- TQString newName = KInputDialog::getText( i18n( "Rename Tag" ), i18n( "Provide a new name for tag '%1':" ).tqarg( oldName ) );
+ TQString newName = KInputDialog::getText( i18n( "Rename Tag" ), i18n( "Provide a new name for tag '%1':" ).arg( oldName ) );
if ( !newName.isEmpty() )
{
KURL url( "http://del.icio.us/api/tags/rename" );
@@ -334,7 +334,7 @@ void MainWidget::slotDeleteBookmark()
BookmarkListItem * bookmark = static_cast<BookmarkListItem *>( lvBookmarks->currentItem() );
if ( bookmark )
{
- int result = KMessageBox::warningContinueCancel( this, i18n( "Do you really want to remove the bookmark\n%1?" ).tqarg( bookmark->desc() ),
+ int result = KMessageBox::warningContinueCancel( this, i18n( "Do you really want to remove the bookmark\n%1?" ).arg( bookmark->desc() ),
i18n( "Delete Bookmark" ), KStdGuiItem::del() );
if ( result == KMessageBox::Continue )
diff --git a/konq-plugins/sidebar/metabar/src/defaultplugin.cpp b/konq-plugins/sidebar/metabar/src/defaultplugin.cpp
index e6c594c..b199b58 100644
--- a/konq-plugins/sidebar/metabar/src/defaultplugin.cpp
+++ b/konq-plugins/sidebar/metabar/src/defaultplugin.cpp
@@ -156,7 +156,7 @@ void DefaultPlugin::loadApplications(DOM::HTMLElement node)
KDesktopFile desktop(url.path(), TRUE);
if(desktop.hasApplicationType ()){
- MetabarWidget::addEntry(innerHTML, i18n("Run %1").tqarg(desktop.readName()), "desktop://" + url.path(), desktop.readIcon());
+ MetabarWidget::addEntry(innerHTML, i18n("Run %1").arg(desktop.readName()), "desktop://" + url.path(), desktop.readIcon());
m_functions->show("open");
}
@@ -364,12 +364,12 @@ void DefaultPlugin::slotSetPreview(const KFileItem *item, const TQPixmap &pix)
buffer.open(IO_WriteOnly);
pix.save(&buffer, "PNG");
- TQString src = TQString::fromLatin1("data:image/png;base64,%1").tqarg(KCodecs::base64Encode(data).data());
+ TQString src = TQString::fromLatin1("data:image/png;base64,%1").arg(KCodecs::base64Encode(data).data());
bool media = item->mimetype().startsWith("video/");
DOM::DOMString innerHTML;
- innerHTML += TQString("<ul style=\"height: %1px\"><a class=\"preview\"").tqarg(pix.height() + 15);
+ innerHTML += TQString("<ul style=\"height: %1px\"><a class=\"preview\"").arg(pix.height() + 15);
if(media){
innerHTML += " href=\"preview:///\"";
diff --git a/konq-plugins/sidebar/metabar/src/metabarfunctions.cpp b/konq-plugins/sidebar/metabar/src/metabarfunctions.cpp
index f7bc152..1aaf9e8 100644
--- a/konq-plugins/sidebar/metabar/src/metabarfunctions.cpp
+++ b/konq-plugins/sidebar/metabar/src/metabarfunctions.cpp
@@ -81,7 +81,7 @@ void MetabarFunctions::toggle(DOM::DOMString item)
DOM::HTMLElement node = static_cast<DOM::HTMLElement>(doc.getElementById(item));
if(!node.isNull()){
- DOM::NodeList tqchildren = node.childNodes();
+ DOM::NodeList children = node.childNodes();
DOM::CSSStyleDeclaration style = node.style();
DOM::DOMString expanded = node.getAttribute("expanded");
@@ -106,7 +106,7 @@ void MetabarFunctions::toggle(DOM::DOMString item)
}
}
else{
- style.setProperty("height", TQString("%1px").tqarg(height), CSS_PRIORITY);
+ style.setProperty("height", TQString("%1px").arg(height), CSS_PRIORITY);
}
}
}
@@ -117,7 +117,7 @@ void MetabarFunctions::adjustSize(DOM::DOMString item)
DOM::HTMLElement node = static_cast<DOM::HTMLElement>(doc.getElementById(item));
if(!node.isNull()){
- DOM::NodeList tqchildren = node.childNodes();
+ DOM::NodeList children = node.childNodes();
DOM::CSSStyleDeclaration style = node.style();
DOM::DOMString expanded = node.getAttribute("expanded");
@@ -137,7 +137,7 @@ void MetabarFunctions::adjustSize(DOM::DOMString item)
}
}
else{
- style.setProperty("height", TQString("%1px").tqarg(height), CSS_PRIORITY);
+ style.setProperty("height", TQString("%1px").arg(height), CSS_PRIORITY);
}
}
}
@@ -176,7 +176,7 @@ void MetabarFunctions::animate()
}
int change = currentHeight < height ? changeValue : -changeValue;
- style.setProperty("height", TQString("%1px").tqarg(currentHeight + change), CSS_PRIORITY);
+ style.setProperty("height", TQString("%1px").arg(currentHeight + change), CSS_PRIORITY);
doc.updateRendering();
}
}
@@ -209,9 +209,9 @@ void MetabarFunctions::hide(DOM::DOMString item)
int MetabarFunctions::getHeight(DOM::HTMLElement &element)
{
int height = 0;
- DOM::NodeList tqchildren = element.childNodes();
- for(uint i = 0; i < tqchildren.length(); i++){
- DOM::HTMLElement node = static_cast<DOM::HTMLElement>(tqchildren.item(i));
+ DOM::NodeList children = element.childNodes();
+ for(uint i = 0; i < children.length(); i++){
+ DOM::HTMLElement node = static_cast<DOM::HTMLElement>(children.item(i));
DOM::CSSStyleDeclaration style = node.style();
DOM::DOMString css_height = style.getPropertyValue("height");
diff --git a/konq-plugins/sidebar/metabar/src/metabarwidget.cpp b/konq-plugins/sidebar/metabar/src/metabarwidget.cpp
index 700cb74..05ce39a 100644
--- a/konq-plugins/sidebar/metabar/src/metabarwidget.cpp
+++ b/konq-plugins/sidebar/metabar/src/metabarwidget.cpp
@@ -118,7 +118,7 @@ MetabarWidget::MetabarWidget(TQWidget *parent, const char *name) : TQWidget(pare
tqlayout->addWidget(html->view());
popup = new KPopupMenu(0);
- KAction *configAction = new KAction(i18n("Configure %1...").tqarg("Metabar"), "configure", KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotShowConfig()), html->actionCollection(), "configure");
+ KAction *configAction = new KAction(i18n("Configure %1...").arg("Metabar"), "configure", KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotShowConfig()), html->actionCollection(), "configure");
configAction->plug(popup);
KAction *reloadAction = new KAction(i18n("Reload Theme"), "reload", KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(setTheme()), html->actionCollection(), "reload");
@@ -289,7 +289,7 @@ void MetabarWidget::loadCompleted()
if(node.hasAttribute("image")){
TQString icon = node.getAttribute("image").string();
TQString url = getIconPath(icon);
- TQString style = TQString("background-image: url(%1);").tqarg(url);
+ TQString style = TQString("background-image: url(%1);").arg(url);
node.setAttribute("style", style);
}
@@ -308,7 +308,7 @@ void MetabarWidget::loadCompleted()
}
config->setGroup("General");
- TQString file = locate("data", TQString("metabar/themes/%1/default.css").tqarg(config->readEntry("Theme", "default")));
+ TQString file = locate("data", TQString("metabar/themes/%1/default.css").arg(config->readEntry("Theme", "default")));
if(file.isNull()){
file = locate("data", TQString("metabar/themes/default/default.css"));
}
@@ -393,7 +393,7 @@ void MetabarWidget::handleURLRequest(const KURL &url, const KParts::URLArgs &arg
skip = true; //needed to prevent some weired reload
DOM::DOMString innerHTML;
- innerHTML += TQString("<ul style=\"width: %1px; height: %1px\">").tqarg(image.width(), image.height());
+ innerHTML += TQString("<ul style=\"width: %1px; height: %1px\">").arg(image.width(), image.height());
innerHTML += "<object class=\"preview\" type=\"";
innerHTML += item->mimetype();
innerHTML += "\" data=\"";
@@ -431,7 +431,7 @@ void MetabarWidget::handleURLRequest(const KURL &url, const KParts::URLArgs &arg
}
if(element.id().string().startsWith("hidden")){
- TQString style = TQString("background-image: url(%1);").tqarg(getIconPath(showMore ? "1downarrow" : "1uparrow"));
+ TQString style = TQString("background-image: url(%1);").arg(getIconPath(showMore ? "1downarrow" : "1uparrow"));
element.setInnerText( showMore ? i18n("More") : i18n("Less") );
element.setAttribute("style", style);
}
@@ -475,7 +475,7 @@ TQString MetabarWidget::getIconPath(const TQString &name)
buffer.open(IO_WriteOnly);
icon.save(&buffer, "PNG");
- return TQString::fromLatin1("data:image/png;base64,%1").tqarg(KCodecs::base64Encode(data).data());
+ return TQString::fromLatin1("data:image/png;base64,%1").arg(KCodecs::base64Encode(data).data());
}
void MetabarWidget::slotShowSharingDialog()
@@ -584,7 +584,7 @@ void MetabarWidget::setTheme()
loadComplete = false;
config->setGroup("General");
- TQString file = locate("data", TQString("metabar/themes/%1/tqlayout.html").tqarg(config->readEntry("Theme", "default")));
+ TQString file = locate("data", TQString("metabar/themes/%1/tqlayout.html").arg(config->readEntry("Theme", "default")));
html->openURL(KURL(file));
}
diff --git a/konq-plugins/sidebar/metabar/src/protocolplugin.cpp b/konq-plugins/sidebar/metabar/src/protocolplugin.cpp
index 1779b37..8daf5ba 100644
--- a/konq-plugins/sidebar/metabar/src/protocolplugin.cpp
+++ b/konq-plugins/sidebar/metabar/src/protocolplugin.cpp
@@ -71,7 +71,7 @@ void ProtocolPlugin::setFileItems(const KFileItemList &items)
TQBuffer buffer(data);
buffer.open(IO_WriteOnly);
pix.save(&buffer, "PNG");
- TQString icondata = TQString::fromLatin1("data:image/png;base64,%1").tqarg(KCodecs::base64Encode(data).data());
+ TQString icondata = TQString::fromLatin1("data:image/png;base64,%1").arg(KCodecs::base64Encode(data).data());
icon.setSrc(icondata);
}
@@ -81,7 +81,7 @@ void ProtocolPlugin::setFileItems(const KFileItemList &items)
name.setInnerText(m_items.getFirst()->name());
}
else{
- name.setInnerText(i18n("%1 Elements").tqarg(m_items.count()));
+ name.setInnerText(i18n("%1 Elements").arg(m_items.count()));
}
}
@@ -105,7 +105,7 @@ void ProtocolPlugin::setFileItems(const KFileItemList &items)
}
}
- type.setInnerText(i18n("%1 Folders, %2 Files").tqarg(dirs).tqarg(files));
+ type.setInnerText(i18n("%1 Folders, %2 Files").arg(dirs).arg(files));
}
diff --git a/konq-plugins/uachanger/uachangerplugin.cpp b/konq-plugins/uachanger/uachangerplugin.cpp
index dbafc59..a9efc26 100644
--- a/konq-plugins/uachanger/uachangerplugin.cpp
+++ b/konq-plugins/uachanger/uachangerplugin.cpp
@@ -135,21 +135,21 @@ void UAChangerPlugin::parseDescFiles()
continue; // Ignore dups!
m_lstIdentity << tmp;
- tmp = TQString("%1 %2").tqarg(UA_PTOS("X-KDE-UA-SYSNAME")).tqarg(UA_PTOS("X-KDE-UA-SYSRELEASE"));
+ tmp = TQString("%1 %2").arg(UA_PTOS("X-KDE-UA-SYSNAME")).arg(UA_PTOS("X-KDE-UA-SYSRELEASE"));
if ( tmp.stripWhiteSpace().isEmpty() )
{
if(tag == "NN" || tag == "IE" || tag == "MOZ")
- tmp = i18n("Version %1").tqarg(UA_PTOS("X-KDE-UA-VERSION"));
+ tmp = i18n("Version %1").arg(UA_PTOS("X-KDE-UA-VERSION"));
else
- tmp = TQString("%1 %2").tqarg(UA_PTOS("X-KDE-UA-NAME")).tqarg(UA_PTOS("X-KDE-UA-VERSION"));
+ tmp = TQString("%1 %2").arg(UA_PTOS("X-KDE-UA-NAME")).arg(UA_PTOS("X-KDE-UA-VERSION"));
}
else
{
if(tag == "NN" || tag == "IE" || tag == "MOZ")
- tmp = i18n("Version %1 on %2").tqarg(UA_PTOS("X-KDE-UA-VERSION")).tqarg(tmp);
+ tmp = i18n("Version %1 on %2").arg(UA_PTOS("X-KDE-UA-VERSION")).arg(tmp);
else
- tmp = i18n("%1 %2 on %3").tqarg(UA_PTOS("X-KDE-UA-NAME")).tqarg(UA_PTOS("X-KDE-UA-VERSION")).tqarg(tmp);
+ tmp = i18n("%1 %2 on %3").arg(UA_PTOS("X-KDE-UA-NAME")).arg(UA_PTOS("X-KDE-UA-VERSION")).arg(tmp);
}
m_lstAlias << tmp;
diff --git a/konq-plugins/validators/plugin_validators.cpp b/konq-plugins/validators/plugin_validators.cpp
index fe61ae3..f669308 100644
--- a/konq-plugins/validators/plugin_validators.cpp
+++ b/konq-plugins/validators/plugin_validators.cpp
@@ -184,7 +184,7 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
i18n("<qt>The selected URL cannot be verified because it contains "
"a password. Sending this URL to <b>%1</b> would put the security "
"of <b>%2</b> at risk.</qt>")
- .tqarg(validatorUrl.host()).tqarg(partUrl.host()));
+ .arg(validatorUrl.host()).arg(partUrl.host()));
return;
}
// Set entered URL as a parameter
diff --git a/konq-plugins/webarchiver/archivedialog.cpp b/konq-plugins/webarchiver/archivedialog.cpp
index b72ca42..24b49b8 100644
--- a/konq-plugins/webarchiver/archivedialog.cpp
+++ b/konq-plugins/webarchiver/archivedialog.cpp
@@ -88,7 +88,7 @@ void ArchiveDialog::archive()
} else {
const TQString title = i18n( "Unable to Open Web-Archive" );
- const TQString text = i18n( "Unable to open \n %1 \n for writing." ).tqarg(m_tarBall->fileName());
+ const TQString text = i18n( "Unable to open \n %1 \n for writing." ).arg(m_tarBall->fileName());
KMessageBox::sorry( 0L, text, title );
}
}
@@ -207,7 +207,7 @@ static bool hasChildNode(const DOM::Node &pNode, const TQString &nodeName)
}
catch (...)
{
- // No tqchildren, stop recursion here
+ // No children, stop recursion here
child = DOM::Node();
}
@@ -346,7 +346,7 @@ void ArchiveDialog::saveArchiveRecursive(const DOM::Node &pNode, const KURL& bas
}
catch (...)
{
- // No tqchildren, stop recursion here
+ // No children, stop recursion here
child = DOM::Node();
}
diff --git a/konq-plugins/webarchiver/plugin_webarchiver.cpp b/konq-plugins/webarchiver/plugin_webarchiver.cpp
index 85d43ee..c76f56c 100644
--- a/konq-plugins/webarchiver/plugin_webarchiver.cpp
+++ b/konq-plugins/webarchiver/plugin_webarchiver.cpp
@@ -94,7 +94,7 @@ void PluginWebArchiver::slotSaveToArchive()
if (!(url.isValid())) {
const TQString title = i18n( "Invalid URL" );
- const TQString text = i18n( "The URL\n%1\nis not valid." ).tqarg(url.prettyURL());
+ const TQString text = i18n( "The URL\n%1\nis not valid." ).arg(url.prettyURL());
KMessageBox::sorry(part->widget(), text, title );
return;
}
@@ -102,7 +102,7 @@ void PluginWebArchiver::slotSaveToArchive()
const TQFile file(url.path());
if (file.exists()) {
const TQString title = i18n( "File Exists" );
- const TQString text = i18n( "Do you really want to overwrite:\n%1?" ).tqarg(url.prettyURL());
+ const TQString text = i18n( "Do you really want to overwrite:\n%1?" ).arg(url.prettyURL());
if (KMessageBox::Continue != KMessageBox::warningContinueCancel( part->widget(), text, title, i18n("Overwrite") ) ) {
return;
}
diff --git a/konq-plugins/fsview/treemap.cpp b/konq-plugins/fsview/treemap.cpp
index bcc5b3e..cab9809 100644
--- a/konq-plugins/fsview/treemap.cpp
+++ b/konq-plugins/fsview/treemap.cpp
@@ -756,7 +756,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
_parent = parent;
_sum = 0;
- _tqchildren = 0;
+ _children = 0;
_widget = 0;
_index = -1;
_depth = -1; // not set
@@ -789,7 +789,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
setText(0, text1);
_sum = 0;
- _tqchildren = 0;
+ _children = 0;
_widget = 0;
_index = -1;
_depth = -1; // not set
@@ -801,7 +801,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
TreeMapItem::~TreeMapItem()
{
- if (_tqchildren) delete _tqchildren;
+ if (_children) delete _children;
if (_freeRects) delete _freeRects;
// finally, notify widget about deletion
@@ -842,18 +842,18 @@ void TreeMapItem::redraw()
void TreeMapItem::clear()
{
- if (_tqchildren) {
+ if (_children) {
// delete selected items below this item from selection
if (_widget) _widget->clearSelection(this);
- delete _tqchildren;
- _tqchildren = 0;
+ delete _children;
+ _children = 0;
}
}
// invalidates current tqchildren and forces redraw
// this is only usefull when tqchildren are created on demand in items()
void TreeMapItem::refresh()
{
clear();
@@ -887,9 +887,9 @@ int TreeMapItem::depth() const
bool TreeMapItem::initialized()
{
- if (!_tqchildren) {
- _tqchildren = new TreeMapItemList;
- _tqchildren->setAutoDelete(true);
+ if (!_children) {
+ _children = new TreeMapItemList;
+ _children->setAutoDelete(true);
return false;
}
return true;
@@ -899,16 +899,16 @@ void TreeMapItem::addItem(TreeMapItem* i)
{
if (!i) return;
- if (!_tqchildren) {
- _tqchildren = new TreeMapItemList;
- _tqchildren->setAutoDelete(true);
+ if (!_children) {
+ _children = new TreeMapItemList;
+ _children->setAutoDelete(true);
}
i->setParent(this);
if (sorting(0) == -1)
- _tqchildren->append(i); // preserve insertion order
+ _children->append(i); // preserve insertion order
else
- _tqchildren->inSort(i);
+ _children->inSort(i);
}
@@ -974,17 +974,17 @@ void TreeMapItem::setSorting(int textNo, bool ascending)
_sortAscending = ascending;
_sortTextNo = textNo;
- if (_tqchildren && _sortTextNo != -1) _tqchildren->sort();
+ if (_children && _sortTextNo != -1) _children->sort();
}
void TreeMapItem::resort(bool recursive)
{
- if (!_tqchildren) return;
+ if (!_children) return;
- if (_sortTextNo != -1) _tqchildren->sort();
+ if (_sortTextNo != -1) _children->sort();
if (recursive)
- for (TreeMapItem* i=_tqchildren->first(); i; i=_tqchildren->next())
+ for (TreeMapItem* i=_children->first(); i; i=_children->next())
i->resort(recursive);
}
@@ -1002,13 +1002,13 @@ int TreeMapItem::rtti() const
return 0;
}
-TreeMapItemList* TreeMapItem::tqchildren()
+TreeMapItemList* TreeMapItem::children()
{
- if (!_tqchildren) {
- _tqchildren = new TreeMapItemList;
- _tqchildren->setAutoDelete(true);
+ if (!_children) {
+ _children = new TreeMapItemList;
+ _children->setAutoDelete(true);
}
- return _tqchildren;
+ return _children;
}
void TreeMapItem::clearItemRect()
@@ -1252,7 +1252,7 @@ void TreeMapWidget::setMaxDrawingDepth(int d)
TQString TreeMapWidget::defaultFieldType(int f) const
{
- return i18n("Text %1").tqarg(f+1);
+ return i18n("Text %1").arg(f+1);
}
TQString TreeMapWidget::defaultFieldStop(int) const
@@ -1482,7 +1482,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
if (DEBUG_DRAWING) kdDebug(90100) << "item(" << x << "," << y << "):" << endl;
while (1) {
- TreeMapItemList* list = p->tqchildren();
+ TreeMapItemList* list = p->children();
if (!list)
i = 0;
else {
@@ -1546,12 +1546,12 @@ TreeMapItem* TreeMapWidget::visibleItem(TreeMapItem* i) const
(i->itemRect().height() <1))) {
TreeMapItem* p = i->parent();
if (!p) break;
- int idx = p->tqchildren()->findRef(i);
+ int idx = p->children()->findRef(i);
idx--;
if (idx<0)
i = p;
else
- i = p->tqchildren()->at(idx);
+ i = p->children()->at(idx);
}
}
return i;
@@ -1745,7 +1745,7 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
i2 = i2->parent();
if (!i2) return changed;
- TreeMapItemList* list = commonParent->tqchildren();
+ TreeMapItemList* list = commonParent->children();
if (!list) return changed;
TreeMapItem* i = list->first();
@@ -1768,7 +1768,7 @@ void TreeMapWidget::contextMenuEvent( TQContextMenuEvent* e )
{
//kdDebug(90100) << "TreeMapWidget::contextMenuEvent" << endl;
- if ( tqreceivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
+ if ( receivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
e->accept();
if ( e->reason() == TQContextMenuEvent::Keyboard ) {
@@ -1938,12 +1938,12 @@ int nextVisible(TreeMapItem* i)
TreeMapItem* p = i->parent();
if (!p || p->itemRect().isEmpty()) return -1;
- int idx = p->tqchildren()->findRef(i);
+ int idx = p->children()->findRef(i);
if (idx<0) return -1;
- while (idx < (int)p->tqchildren()->count()-1) {
+ while (idx < (int)p->children()->count()-1) {
idx++;
- TQRect r = p->tqchildren()->at(idx)->itemRect();
+ TQRect r = p->children()->at(idx)->itemRect();
if (r.width()>1 && r.height()>1)
return idx;
}
@@ -1956,12 +1956,12 @@ int prevVisible(TreeMapItem* i)
TreeMapItem* p = i->parent();
if (!p || p->itemRect().isEmpty()) return -1;
- int idx = p->tqchildren()->findRef(i);
+ int idx = p->children()->findRef(i);
if (idx<0) return -1;
while (idx > 0) {
idx--;
- TQRect r = p->tqchildren()->at(idx)->itemRect();
+ TQRect r = p->children()->at(idx)->itemRect();
if (r.width()>1 && r.height()>1)
return idx;
}
@@ -2042,24 +2042,24 @@ void TreeMapWidget::keyPressEvent( TQKeyEvent* e )
int newIdx = goBack ? nextVisible(_current) : prevVisible(_current);
if (p && newIdx>=0) {
p->setIndex(newIdx);
- setCurrent(p->tqchildren()->at(newIdx), true);
+ setCurrent(p->children()->at(newIdx), true);
}
}
else if (e->key() == Key_Right) {
int newIdx = goBack ? prevVisible(_current) : nextVisible(_current);
if (p && newIdx>=0) {
p->setIndex(newIdx);
- setCurrent(p->tqchildren()->at(newIdx), true);
+ setCurrent(p->children()->at(newIdx), true);
}
}
else if (e->key() == Key_Down) {
- if (_current->tqchildren() && _current->tqchildren()->count()>0) {
+ if (_current->children() && _current->children()->count()>0) {
int newIdx = _current->index();
if (newIdx<0)
- newIdx = goBack ? (_current->tqchildren()->count()-1) : 0;
- if (newIdx>=(int)_current->tqchildren()->count())
- newIdx = _current->tqchildren()->count()-1;
- newItem = visibleItem(_current->tqchildren()->at(newIdx));
+ newIdx = goBack ? (_current->children()->count()-1) : 0;
+ if (newIdx>=(int)_current->children()->count())
+ newIdx = _current->children()->count()-1;
+ newItem = visibleItem(_current->children()->at(newIdx));
setCurrent(newItem, true);
}
}
@@ -2245,12 +2245,12 @@ void TreeMapWidget::drawItems(TQPainter* p,
TQRect r = TQRect(origRect.x()+bw, origRect.y()+bw,
origRect.width()-2*bw, origRect.height()-2*bw);
- TreeMapItemList* list = item->tqchildren();
+ TreeMapItemList* list = item->children();
TreeMapItem* i;
bool stopDrawing = false;
// only subdivide if there are tqchildren
if (!list || list->count()==0)
stopDrawing = true;
@@ -2283,7 +2283,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
if (stopDrawing) {
if (list) {
- // tqinvalidate rects
+ // invalidate rects
for (i=list->first();i;i=list->next())
i->clearItemRect();
}
@@ -2399,7 +2399,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
r.setRect(r.x(), r.y()+sr.height(), r.width(), r.height()-sr.height());
}
// set selfRect (not occupied by tqchildren) for tooltip
item->addFreeRect(sr);
if (0) kdDebug(90100) << "Item " << item->path(0).join("/") << ": SelfR "
@@ -2537,7 +2537,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
}
// fills area with a pattern if to small to draw tqchildren
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
{
p->setBrush(TQt::Dense4Pattern);
@@ -2546,7 +2546,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
i->addFreeRect(r);
}
// fills area with a pattern if to small to draw tqchildren
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r,
TreeMapItemListIterator it, int len, bool goBack)
{
@@ -2845,10 +2845,10 @@ void TreeMapWidget::addVisualizationItems(TQPopupMenu* popup, int id)
popup->insertItem(i18n("Border"), bpopup, id+1);
bpopup->insertItem(i18n("Correct Borders Only"), id+2);
bpopup->insertSeparator();
- bpopup->insertItem(i18n("Width %1").tqarg(0), id+3);
- bpopup->insertItem(i18n("Width %1").tqarg(1), id+4);
- bpopup->insertItem(i18n("Width %1").tqarg(2), id+5);
- bpopup->insertItem(i18n("Width %1").tqarg(3), id+6);
+ bpopup->insertItem(i18n("Width %1").arg(0), id+3);
+ bpopup->insertItem(i18n("Width %1").arg(1), id+4);
+ bpopup->insertItem(i18n("Width %1").arg(2), id+5);
+ bpopup->insertItem(i18n("Width %1").arg(3), id+6);
bpopup->setItemChecked(id+2, skipIncorrectBorder());
bpopup->setItemChecked(id+3, borderWidth()==0);
bpopup->setItemChecked(id+4, borderWidth()==1);
@@ -2955,7 +2955,7 @@ void TreeMapWidget::addFieldStopItems(TQPopupMenu* popup,
connect(popup, TQT_SIGNAL(activated(int)),
this, TQT_SLOT(fieldStopActivated(int)));
- popup->insertItem(i18n("No %1 Limit").tqarg(fieldType(0)), id);
+ popup->insertItem(i18n("No %1 Limit").arg(fieldType(0)), id);
popup->setItemChecked(id, fieldStop(0).isEmpty());
_menuItem = i;
bool foundFieldStop = false;
@@ -3014,7 +3014,7 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
int area = i->width() * i->height();
popup->insertSeparator();
popup->insertItem(i18n("Area of '%1' (%2)")
- .tqarg(i->text(0)).tqarg(area), id+1);
+ .arg(i->text(0)).arg(area), id+1);
if (area == minimalArea()) {
popup->setItemChecked(id+1, true);
foundArea = true;
@@ -3040,9 +3040,9 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
}
popup->insertItem(i18n("Double Area Limit (to %1)")
- .tqarg(minimalArea()*2), id+5);
+ .arg(minimalArea()*2), id+5);
popup->insertItem(i18n("Halve Area Limit (to %1)")
- .tqarg(minimalArea()/2), id+6);
+ .arg(minimalArea()/2), id+6);
}
}
@@ -3079,7 +3079,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
int d = i->depth();
popup->insertSeparator();
popup->insertItem(i18n("Depth of '%1' (%2)")
- .tqarg(i->text(0)).tqarg(d), id+1);
+ .arg(i->text(0)).arg(d), id+1);
if (d == maxDrawingDepth()) {
popup->setItemChecked(id+1, true);
foundDepth = true;
@@ -3089,7 +3089,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
popup->insertSeparator();
int depth = 2, count;
for (count=0;count<3;count++) {
- popup->insertItem(i18n("Depth %1").tqarg(depth), id+4+count);
+ popup->insertItem(i18n("Depth %1").arg(depth), id+4+count);
if (depth == maxDrawingDepth()) {
popup->setItemChecked(id+4+count, true);
foundDepth = true;
@@ -3100,14 +3100,14 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
if (maxDrawingDepth()>1) {
popup->insertSeparator();
if (!foundDepth) {
- popup->insertItem(i18n("Depth %1").tqarg(maxDrawingDepth()), id+10);
+ popup->insertItem(i18n("Depth %1").arg(maxDrawingDepth()), id+10);
popup->setItemChecked(id+10, true);
}
popup->insertItem(i18n("Decrement (to %1)")
- .tqarg(maxDrawingDepth()-1), id+2);
+ .arg(maxDrawingDepth()-1), id+2);
popup->insertItem(i18n("Increment (to %1)")
- .tqarg(maxDrawingDepth()+1), id+3);
+ .arg(maxDrawingDepth()+1), id+3);
}
}
@@ -3130,13 +3130,13 @@ void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
int f, fCount = _attr.size();
config->writeEntry(prefix+"FieldCount", fCount);
for (f=0;f<fCount;f++) {
- config->writeEntry(TQString(prefix+"FieldVisible%1").tqarg(f),
+ config->writeEntry(TQString(prefix+"FieldVisible%1").arg(f),
_attr[f].visible);
- config->writeEntry(TQString(prefix+"FieldForced%1").tqarg(f),
+ config->writeEntry(TQString(prefix+"FieldForced%1").arg(f),
_attr[f].forced);
- config->writeEntry(TQString(prefix+"FieldStop%1").tqarg(f),
+ config->writeEntry(TQString(prefix+"FieldStop%1").arg(f),
_attr[f].stop);
- config->writeEntry(TQString(prefix+"FieldPosition%1").tqarg(f),
+ config->writeEntry(TQString(prefix+"FieldPosition%1").arg(f),
fieldPositionString(f));
}
}
@@ -3180,18 +3180,18 @@ void TreeMapWidget::restoreOptions(KConfigGroup* config, TQString prefix)
int f;
for (f=0;f<num;f++) {
- str = TQString(prefix+"FieldVisible%1").tqarg(f);
+ str = TQString(prefix+"FieldVisible%1").arg(f);
if (config->hasKey(str))
setFieldVisible(f, config->readBoolEntry(str));
- str = TQString(prefix+"FieldForced%1").tqarg(f);
+ str = TQString(prefix+"FieldForced%1").arg(f);
if (config->hasKey(str))
setFieldForced(f, config->readBoolEntry(str));
- str = config->readEntry(TQString(prefix+"FieldStop%1").tqarg(f));
+ str = config->readEntry(TQString(prefix+"FieldStop%1").arg(f));
setFieldStop(f, str);
- str = config->readEntry(TQString(prefix+"FieldPosition%1").tqarg(f));
+ str = config->readEntry(TQString(prefix+"FieldPosition%1").arg(f));
if (!str.isEmpty()) setFieldPosition(f, str);
}
}
@@ -842,18 +842,18 @@ void TreeMapItem::redraw()
}
}
-// invalidates current tqchildren and forces redraw
-// this is only usefull when tqchildren are created on demand in items()
+// invalidates current children and forces redraw
+// this is only usefull when children are created on demand in items()
void TreeMapItem::refresh()
{
@@ -2245,12 +2245,12 @@ void TreeMapWidget::drawItems(TQPainter* p,
TreeMapItem* i;
bool stopDrawing = false;
- // only subdivide if there are tqchildren
+ // only subdivide if there are children
if (!list || list->count()==0)
stopDrawing = true;
@@ -2399,7 +2399,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
r.setRect(r.x(), r.y()+sr.height(), r.width(), r.height()-sr.height());
}
- // set selfRect (not occupied by tqchildren) for tooltip
+ // set selfRect (not occupied by children) for tooltip
item->addFreeRect(sr);
if (0) kdDebug(90100) << "Item " << item->path(0).join("/") << ": SelfR "
@@ -2537,7 +2537,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
}
-// fills area with a pattern if to small to draw tqchildren
+// fills area with a pattern if to small to draw children
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
{
@@ -2546,7 +2546,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
i->addFreeRect(r);
}
-// fills area with a pattern if to small to draw tqchildren
+// fills area with a pattern if to small to draw children
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r,
TreeMapItemListIterator it, int len, bool goBack)
diff --git a/konq-plugins/fsview/treemap.h b/konq-plugins/fsview/treemap.h
index 6cb5edd..31ac9d3 100644
--- a/konq-plugins/fsview/treemap.h
+++ b/konq-plugins/fsview/treemap.h
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
*
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
* items on demand, reimplement tqchildren().
*/
class TreeMapItem: public StoredDrawParams
{
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
// delete all tqchildren
void clear();
// force new child generation & refresh
@@ -343,7 +343,7 @@ public:
* For value() sorting, use <textNo> = -2
*
* For fast sorting, set this to -1 before child insertions and call
* again after inserting all tqchildren.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
* Resort according to the already set sorting.
*
* This has to be done if the sorting base changes (e.g. text or values
* change). If this is only true for the tqchildren of this item, you can
* set the recursive parameter to false.
*/
void resort(bool recursive = true);
virtual SplitMode splitMode() const;
virtual int rtti() const;
- // not const as this can create tqchildren on demand
- virtual TreeMapItemList* tqchildren();
+ // not const as this can create children on demand
+ virtual TreeMapItemList* children();
protected:
- TreeMapItemList* _tqchildren;
+ TreeMapItemList* _children;
double _sum, _value;
private:
@@ -436,7 +436,7 @@ public:
/**
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
* has no selected tqchildren or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
* Clear selection of all selected items which are tqchildren of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
*/
@@ -464,7 +464,7 @@ public:
* Range means for a hierarchical widget:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
* range of direct tqchildren between but excluding the child
* leading to i1 and the child leading to i2.
*/
void setRangeSelection(TreeMapItem* i1,
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
* If a tqchildren value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
* parent/child size relation can not be mapped to a correct
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
* Redraws an item with all tqchildren.
* This takes changed values(), sums(), colors() and text() into account.
*/
void redraw(TreeMapItem*);
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
- * items on demand, reimplement tqchildren().
+ * items on demand, reimplement children().
*/
class TreeMapItem: public StoredDrawParams
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
- // delete all tqchildren
+ // delete all children
void clear();
// force new child generation & refresh
@@ -343,7 +343,7 @@ public:
*
* For fast sorting, set this to -1 before child insertions and call
- * again after inserting all tqchildren.
+ * again after inserting all children.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
*
* This has to be done if the sorting base changes (e.g. text or values
- * change). If this is only true for the tqchildren of this item, you can
+ * change). If this is only true for the children of this item, you can
* set the recursive parameter to false.
*/
@@ -436,7 +436,7 @@ public:
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
- * has no selected tqchildren or parents stays true.
+ * has no selected children or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
- * Clear selection of all selected items which are tqchildren of
+ * Clear selection of all selected items which are children of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
@@ -464,7 +464,7 @@ public:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
- * range of direct tqchildren between but excluding the child
+ * range of direct children between but excluding the child
* leading to i1 and the child leading to i2.
*/
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
- * If a tqchildren value() is almost the parents sum(),
+ * If a children value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
- * Redraws an item with all tqchildren.
+ * Redraws an item with all children.
* This takes changed values(), sums(), colors() and text() into account.
*/